@@ -9,7 +9,7 @@
 #include "scrollingdialog.h"
 #include "filegroupsandmasks.h"
 
-class ProjectsFileMasksDlg : public wxScrollingDialog
+class DLLIMPORT ProjectsFileMasksDlg : public wxScrollingDialog
 {
     public:
         ProjectsFileMasksDlg(wxWindow* parent, FilesGroupsAndMasks* fgam);
@@ -27,9 +27,10 @@ class ProjectsFileMasksDlg : public wxScrollingDialog
         void ListChange();
 
         virtual void EndModal(int retCode);
-        FilesGroupsAndMasks m_FileGroups;
-        FilesGroupsAndMasks* m_pOrigFileGroups;
-        int m_LastListSelection;
+
+        FilesGroupsAndMasks  m_FileGroupsAndMasksCopy;
+        FilesGroupsAndMasks* m_pFileGroupsAndMasks;
+        int                  m_LastListSelection;
 
         DECLARE_EVENT_TABLE();
 };
